@@ -102,7 +102,7 @@ sub share_from {
         $type = $1 if ( $var = $arg ) =~ s/^(\W)//;
         for ( 1 .. 2 ) {    # assign twice to avoid any 'used once' warnings
             *{$var} =
-                ( !$type ) ? \&{ $pkg . "::$var" }
+                ( !$type )       ? \&{ $pkg . "::$var" }
               : ( $type eq '&' ) ? \&{ $pkg . "::$var" }
               : ( $type eq '$' ) ? \${ $pkg . "::$var" }
               : ( $type eq '@' ) ? \@{ $pkg . "::$var" }
@@ -123,7 +123,7 @@ sub jail_reval {
     # the "no safe wrap" reval
     my $nosw_reval = $reval;
     if ( $reval !~ /^sub\{return\(.*\}$/ ) {
-        $nosw_reval =~ s/^sub{(.*)}$/sub{return($1)}/;
+        $nosw_reval =~ s/^sub\{(.*)\}$/sub{return($1)}/;
     }
 
     return (
